@@ -3,14 +3,15 @@
     heights = rep(1, nrow(mat)), ...) {
     interval = ani.options("interval")
     nmax = ani.options("nmax")
-    x = apply(matrix(replicate(obs, FUN(nmax)), nmax), 2, cumsum)
-    xbar = x/matrix(1:nmax, nrow = nmax, ncol = obs)
-    pvalue = apply(xbar, 1, function(xx) shapiro.test(xx)$p.value)
+    x = matrix(nrow = nmax, ncol = obs)
+    for (i in 1:nmax) x[i, ] = apply(matrix(replicate(obs,
+        FUN(i)), i), 2, mean)
+    pvalue = apply(x, 1, function(xx) shapiro.test(xx)$p.value)
     layout(mat, widths, heights)
     for (i in 1:nmax) {
-        hist(xbar[i, ], freq = FALSE, main = "", xlab = substitute(italic(bar(x)[i]),
+        hist(x[i, ], freq = FALSE, main = "", xlab = substitute(italic(bar(x)[i]),
             list(i = i)), col = col[1])
-        lines(density(xbar[i, ]), col = col[2])
+        lines(density(x[i, ]), col = col[2])
         legend("topright", legend = paste("P-value:", format(round(pvalue[i],
             3), nsmall = 3)), bty = "n")
         plot(pvalue[1:i], xlim = c(1, nmax), ylim = range(pvalue),
